@@ -6,7 +6,8 @@
 #' @param replacement Character string equal in length to pattern or of length 
 #' one which are  a replacement for matched pattern.
 #' @param endmarks The potential ending punctuation marks.
-#' @param \dots Additional arguments passed to \code{\link[textclean]{has_endmark}}.
+#' @param \dots Additional arguments passed to 
+#' \code{\link[textclean]{has_endmark}}.
 #' @return Returns a vector with missing endmarks added.
 #' @export
 #' @examples 
@@ -18,7 +19,8 @@
 #' )
 #' 
 #' add_missing_endmark(x)
-add_missing_endmark <- function(x, replacement = "|", endmarks = c("?", ".", "!"), ...){
+add_missing_endmark <- function(x, replacement = "|", 
+    endmarks = c("?", ".", "!"), ...){
 
     locs <- which(!has_endmark(x, ...))
     x[locs] <- paste0(x[locs], replacement)
