@@ -11,7 +11,8 @@
 #' replacements.
 #' @param trailspace logical.  If \code{TRUE} inserts a trailing space in the 
 #' replacements.
-#' @param fixed logical. If \code{TRUE}, pattern is a string to be matched as is. 
+#' @param fixed logical. If \code{TRUE}, pattern is a string to be matched as 
+#' is. 
 #' Overrides all conflicting arguments.
 #' @param trim logical.  If \code{TRUE} leading and trailing white spaces are 
 #' removed and multiple white spaces are reduced to a single white space.
@@ -23,7 +24,8 @@
 #' the backend and performs safe substitutions.  The trade-off is that this mode
 #' will slow the replacements down considerably.
 #' @param \dots Additional arguments passed to \code{\link[base]{gsub}}. In 
-#' \code{mgsub_regex_safe} this is other arguments passed to \code{\link[mgsub]{mgsub}}.
+#' \code{mgsub_regex_safe} this is other arguments passed to 
+#' \code{\link[mgsub]{mgsub}}.
 #' @return \code{mgsub} - Returns a vector with the pattern replaced.
 #' @seealso \code{\link[textclean]{replace_tokens}}
 #' \code{\link[base]{gsub}}
@@ -36,15 +38,21 @@
 #' library(textclean)
 #' hunthou <- replace_number(seq_len(1e5)) 
 #' 
-#' textclean::mgsub("'twenty thousand three hundred five' into 20305", hunthou, seq_len(1e5))
+#' textclean::mgsub(
+#'     "'twenty thousand three hundred five' into 20305", 
+#'     hunthou, 
+#'     seq_len(1e5)
+#' )
 #' ## "'20305' into 20305"
 #' 
 #' ## Larger example from: https://stackoverflow.com/q/18332463/1000343
 #' ## A slower approach
 #' fivehunthou <- replace_number(seq_len(5e5)) 
 #' 
-#' testvect <- c("fifty seven", "four hundred fifty seven", "six thousand four hundred fifty seven", 
-#'     "forty six thousand four hundred fifty seven", "forty six thousand four hundred fifty seven", 
+#' testvect <- c("fifty seven", "four hundred fifty seven", 
+#'     "six thousand four hundred fifty seven", 
+#'     "forty six thousand four hundred fifty seven", 
+#'     "forty six thousand four hundred fifty seven", 
 #'     "three hundred forty six thousand four hundred fifty seven"
 #' )
 #' 
@@ -63,32 +71,55 @@ mgsub <- function (x, pattern, replacement, leadspace = FALSE,
     safe = FALSE, ...) {
 
     if (!is.null(list(...)$ignore.case) & fixed) {
-        warning('`ignore.case = TRUE` can\'t be used with `fixed = TRUE`.\nDo you want to set `fixed = FALSE`?')    
+        warning(
+            paste0('`ignore.case = TRUE` can\'t be used with `fixed = TRUE`.\n',
+                'Do you want to set `fixed = FALSE`?'
+            ),
+            call. = FALSE
+        )    
     }
     
     if (safe) {
-        return(mgsub_regex_safe(x = x, pattern = pattern, replacement = replacement, ...))
+        return(mgsub_regex_safe(x = x, pattern = pattern, 
+            replacement = replacement, ...))
     }
     
-    if (leadspace | trailspace) replacement <- spaste(replacement, trailing = trailspace, leading = leadspace)
+    if (leadspace | trailspace) {
+        replacement <- spaste(
+            replacement, 
+            trailing = trailspace, 
+            leading = leadspace
+        )
+    }
 
     if (fixed && order.pattern) {
         ord <- rev(order(nchar(pattern)))
         pattern <- pattern[ord]
         if (length(replacement) != 1) replacement <- replacement[ord]
     }
-    if (length(replacement) == 1) replacement <- rep(replacement, length(pattern))
+    
+    if (length(replacement) == 1) {
+        replacement <- rep(replacement, length(pattern))
+    }
+    
     if (any(!nzchar(pattern))) {
         good_apples <- which(nzchar(pattern))  
         pattern <- pattern[good_apples]
         replacement <- replacement[good_apples]      
-        warning('Empty pattern found (i.e., `pattern = ""`).\nThis pattern and replacement have been removed.')
+        warning(paste0(
+            'Empty pattern found (i.e., `pattern = ""`).\n', 
+            'This pattern and replacement have been removed.'
+        ), call. = FALSE)
     }
+    
     for (i in seq_along(pattern)){
         x <- gsub(pattern[i], replacement[i], x, fixed = fixed, ...)
     }
 
-    if (trim) x <- gsub("\\s+", " ", gsub("^\\s+|\\s+$", "", x, perl=TRUE), perl=TRUE)
+    if (trim) {
+        x <- gsub("\\s+", " ", gsub("^\\s+|\\s+$", "", x, perl=TRUE), perl=TRUE)
+    }
+    
     x
 }
 
@@ -110,9 +141,9 @@ mgsub_regex <- function(x, pattern, replacement, leadspace = FALSE,
     trailspace = FALSE, fixed = FALSE, trim = FALSE, order.pattern = fixed, 
     ...) {
     
-    mgsub(x = x, pattern = pattern, replacement = replacement, leadspace = leadspace, 
-        trailspace = trailspace, fixed = fixed, trim = trim, order.pattern = order.pattern, 
-        ...
+    mgsub(x = x, pattern = pattern, replacement = replacement, 
+        leadspace = leadspace, trailspace = trailspace, fixed = fixed, 
+        trim = trim, order.pattern = order.pattern, ...
     )
     
 }
